ManiPluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- ManiPluginPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllBatteryInfo(
) → Future< Map< String, dynamic> ?> -
getBatteryHealth(
) → Future< String?> -
getBatteryLevel(
) → Future< int?> -
getBatteryTemperature(
) → Future< double?> -
getChargingStatus(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ManiPluginPlatform
-
getter/setter pair